@@ -1,16 +1,10 @@
 /****************************************************************************
 **
-** This file is part of the KD Soap library.
+** This file is part of the KD Soap project.
 **
-** SPDX-FileCopyrightText: 2011-2021 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+** SPDX-FileCopyrightText: 2011-2022 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 **
-** SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
-**
-** Licensees holding valid commercial KD Soap licenses may use this file in
-** accordance with the KD Soap Commercial License Agreement provided with
-** the Software.
-**
-** Contact info@kdab.com if any conditions of this licensing are not clear to you.
+** SPDX-License-Identifier: MIT
 **
 ****************************************************************************/
 
@@ -19,14 +13,14 @@
 
 #include "wsdl_helloworld.h"
 
-#include <QMainWindow>
+#include <QWidget>
 
 QT_BEGIN_NAMESPACE
 class QLineEdit;
 class QTextBrowser;
 QT_END_NAMESPACE
 
-class MainWindow : public QMainWindow
+class MainWindow : public QWidget
 {
     Q_OBJECT
 public:
